@@ -36,12 +36,11 @@ class DataprocMetastoreGrpcAsyncIOTransport(DataprocMetastoreTransport):
     """gRPC AsyncIO backend transport for DataprocMetastore.
 
     Configures and manages metastore services. Metastore services are
-    fully managed, highly available, auto-scaled, auto-healing,
-    OSS-native deployments of technical metadata management software.
-    Each metastore service exposes a network endpoint through which
-    metadata queries are served. Metadata queries can originate from a
-    variety of sources, including Apache Hive, Apache Presto, and Apache
-    Spark.
+    fully managed, highly available, autoscaled, autohealing, OSS-native
+    deployments of technical metadata management software. Each
+    metastore service exposes a network endpoint through which metadata
+    queries are served. Metadata queries can originate from a variety of
+    sources, including Apache Hive, Apache Presto, and Apache Spark.
 
     The Dataproc Metastore API defines the following resource model:
 
@@ -151,16 +150,16 @@ class DataprocMetastoreGrpcAsyncIOTransport(DataprocMetastoreTransport):
             api_mtls_endpoint (Optional[str]): Deprecated. The mutual TLS endpoint.
                 If provided, it overrides the ``host`` argument and tries to create
                 a mutual TLS channel with client SSL credentials from
-                ``client_cert_source`` or applicatin default SSL credentials.
+                ``client_cert_source`` or application default SSL credentials.
             client_cert_source (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 Deprecated. A callback to provide client SSL certificate bytes and
                 private key bytes, both in PEM format. It is ignored if
                 ``api_mtls_endpoint`` is None.
             ssl_channel_credentials (grpc.ChannelCredentials): SSL credentials
-                for grpc channel. It is ignored if ``channel`` is provided.
+                for the grpc channel. It is ignored if ``channel`` is provided.
             client_cert_source_for_mtls (Optional[Callable[[], Tuple[bytes, bytes]]]):
                 A callback to provide client certificate bytes and private key bytes,
-                both in PEM format. It is used to configure mutual TLS channel. It is
+                both in PEM format. It is used to configure a mutual TLS channel. It is
                 ignored if ``channel`` or ``ssl_channel_credentials`` is provided.
             quota_project_id (Optional[str]): An optional project to use for billing
                 and quota.
@@ -552,5 +551,139 @@ class DataprocMetastoreGrpcAsyncIOTransport(DataprocMetastoreTransport):
             )
         return self._stubs["export_metadata"]
 
+    @property
+    def restore_service(
+        self,
+    ) -> Callable[
+        [metastore.RestoreServiceRequest], Awaitable[operations_pb2.Operation]
+    ]:
+        r"""Return a callable for the restore service method over gRPC.
+
+        Restores a service from a backup.
+
+        Returns:
+            Callable[[~.RestoreServiceRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "restore_service" not in self._stubs:
+            self._stubs["restore_service"] = self.grpc_channel.unary_unary(
+                "/google.cloud.metastore.v1.DataprocMetastore/RestoreService",
+                request_serializer=metastore.RestoreServiceRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["restore_service"]
+
+    @property
+    def list_backups(
+        self,
+    ) -> Callable[
+        [metastore.ListBackupsRequest], Awaitable[metastore.ListBackupsResponse]
+    ]:
+        r"""Return a callable for the list backups method over gRPC.
+
+        Lists backups in a service.
+
+        Returns:
+            Callable[[~.ListBackupsRequest],
+                    Awaitable[~.ListBackupsResponse]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "list_backups" not in self._stubs:
+            self._stubs["list_backups"] = self.grpc_channel.unary_unary(
+                "/google.cloud.metastore.v1.DataprocMetastore/ListBackups",
+                request_serializer=metastore.ListBackupsRequest.serialize,
+                response_deserializer=metastore.ListBackupsResponse.deserialize,
+            )
+        return self._stubs["list_backups"]
+
+    @property
+    def get_backup(
+        self,
+    ) -> Callable[[metastore.GetBackupRequest], Awaitable[metastore.Backup]]:
+        r"""Return a callable for the get backup method over gRPC.
+
+        Gets details of a single backup.
+
+        Returns:
+            Callable[[~.GetBackupRequest],
+                    Awaitable[~.Backup]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "get_backup" not in self._stubs:
+            self._stubs["get_backup"] = self.grpc_channel.unary_unary(
+                "/google.cloud.metastore.v1.DataprocMetastore/GetBackup",
+                request_serializer=metastore.GetBackupRequest.serialize,
+                response_deserializer=metastore.Backup.deserialize,
+            )
+        return self._stubs["get_backup"]
+
+    @property
+    def create_backup(
+        self,
+    ) -> Callable[[metastore.CreateBackupRequest], Awaitable[operations_pb2.Operation]]:
+        r"""Return a callable for the create backup method over gRPC.
+
+        Creates a new backup in a given project and location.
+
+        Returns:
+            Callable[[~.CreateBackupRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "create_backup" not in self._stubs:
+            self._stubs["create_backup"] = self.grpc_channel.unary_unary(
+                "/google.cloud.metastore.v1.DataprocMetastore/CreateBackup",
+                request_serializer=metastore.CreateBackupRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["create_backup"]
+
+    @property
+    def delete_backup(
+        self,
+    ) -> Callable[[metastore.DeleteBackupRequest], Awaitable[operations_pb2.Operation]]:
+        r"""Return a callable for the delete backup method over gRPC.
+
+        Deletes a single backup.
+
+        Returns:
+            Callable[[~.DeleteBackupRequest],
+                    Awaitable[~.Operation]]:
+                A function that, when called, will call the underlying RPC
+                on the server.
+        """
+        # Generate a "stub function" on-the-fly which will actually make
+        # the request.
+        # gRPC handles serialization and deserialization, so we just need
+        # to pass in the functions for each.
+        if "delete_backup" not in self._stubs:
+            self._stubs["delete_backup"] = self.grpc_channel.unary_unary(
+                "/google.cloud.metastore.v1.DataprocMetastore/DeleteBackup",
+                request_serializer=metastore.DeleteBackupRequest.serialize,
+                response_deserializer=operations_pb2.Operation.FromString,
+            )
+        return self._stubs["delete_backup"]
+
 
 __all__ = ("DataprocMetastoreGrpcAsyncIOTransport",)
