@@ -17,7 +17,7 @@ from collections import OrderedDict
 from distutils import util
 import os
 import re
-from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
+from typing import Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
@@ -434,7 +434,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def list_services(
         self,
-        request: metastore.ListServicesRequest = None,
+        request: Union[metastore.ListServicesRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -444,7 +444,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Lists services in a project and location.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.ListServicesRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.ListServicesRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.ListServices][google.cloud.metastore.v1alpha.DataprocMetastore.ListServices].
             parent (str):
@@ -516,7 +516,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def get_service(
         self,
-        request: metastore.GetServiceRequest = None,
+        request: Union[metastore.GetServiceRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -526,7 +526,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Gets the details of a single service.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.GetServiceRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.GetServiceRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.GetService][google.cloud.metastore.v1alpha.DataprocMetastore.GetService].
             name (str):
@@ -589,7 +589,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def create_service(
         self,
-        request: metastore.CreateServiceRequest = None,
+        request: Union[metastore.CreateServiceRequest, dict] = None,
         *,
         parent: str = None,
         service: metastore.Service = None,
@@ -602,7 +602,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         location.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.CreateServiceRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.CreateServiceRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.CreateService][google.cloud.metastore.v1alpha.DataprocMetastore.CreateService].
             parent (str):
@@ -704,7 +704,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def update_service(
         self,
-        request: metastore.UpdateServiceRequest = None,
+        request: Union[metastore.UpdateServiceRequest, dict] = None,
         *,
         service: metastore.Service = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -715,7 +715,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Updates the parameters of a single service.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.UpdateServiceRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.UpdateServiceRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.UpdateService][google.cloud.metastore.v1alpha.DataprocMetastore.UpdateService].
             service (google.cloud.metastore_v1alpha.types.Service):
@@ -805,7 +805,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def delete_service(
         self,
-        request: metastore.DeleteServiceRequest = None,
+        request: Union[metastore.DeleteServiceRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -815,7 +815,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Deletes a single service.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.DeleteServiceRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.DeleteServiceRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.DeleteService][google.cloud.metastore.v1alpha.DataprocMetastore.DeleteService].
             name (str):
@@ -899,7 +899,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def list_metadata_imports(
         self,
-        request: metastore.ListMetadataImportsRequest = None,
+        request: Union[metastore.ListMetadataImportsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -909,7 +909,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Lists imports in a service.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.ListMetadataImportsRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.ListMetadataImportsRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.ListMetadataImports][google.cloud.metastore.v1alpha.DataprocMetastore.ListMetadataImports].
             parent (str):
@@ -981,7 +981,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def get_metadata_import(
         self,
-        request: metastore.GetMetadataImportRequest = None,
+        request: Union[metastore.GetMetadataImportRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -991,7 +991,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Gets details of a single import.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.GetMetadataImportRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.GetMetadataImportRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.GetMetadataImport][google.cloud.metastore.v1alpha.DataprocMetastore.GetMetadataImport].
             name (str):
@@ -1054,7 +1054,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def create_metadata_import(
         self,
-        request: metastore.CreateMetadataImportRequest = None,
+        request: Union[metastore.CreateMetadataImportRequest, dict] = None,
         *,
         parent: str = None,
         metadata_import: metastore.MetadataImport = None,
@@ -1067,7 +1067,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         location.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.CreateMetadataImportRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.CreateMetadataImportRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.CreateMetadataImport][google.cloud.metastore.v1alpha.DataprocMetastore.CreateMetadataImport].
             parent (str):
@@ -1168,7 +1168,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def update_metadata_import(
         self,
-        request: metastore.UpdateMetadataImportRequest = None,
+        request: Union[metastore.UpdateMetadataImportRequest, dict] = None,
         *,
         metadata_import: metastore.MetadataImport = None,
         update_mask: field_mask_pb2.FieldMask = None,
@@ -1181,7 +1181,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         supported to be updated.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.UpdateMetadataImportRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.UpdateMetadataImportRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.UpdateMetadataImport][google.cloud.metastore.v1alpha.DataprocMetastore.UpdateMetadataImport].
             metadata_import (google.cloud.metastore_v1alpha.types.MetadataImport):
@@ -1271,7 +1271,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def export_metadata(
         self,
-        request: metastore.ExportMetadataRequest = None,
+        request: Union[metastore.ExportMetadataRequest, dict] = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
@@ -1280,7 +1280,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Exports metadata from a service.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.ExportMetadataRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.ExportMetadataRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.ExportMetadata][google.cloud.metastore.v1alpha.DataprocMetastore.ExportMetadata].
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
@@ -1332,7 +1332,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def restore_service(
         self,
-        request: metastore.RestoreServiceRequest = None,
+        request: Union[metastore.RestoreServiceRequest, dict] = None,
         *,
         service: str = None,
         backup: str = None,
@@ -1343,7 +1343,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Restores a service from a backup.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.RestoreServiceRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.RestoreServiceRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.Restore][].
             service (str):
@@ -1428,7 +1428,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def list_backups(
         self,
-        request: metastore.ListBackupsRequest = None,
+        request: Union[metastore.ListBackupsRequest, dict] = None,
         *,
         parent: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1438,7 +1438,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Lists backups in a service.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.ListBackupsRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.ListBackupsRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.ListBackups][google.cloud.metastore.v1alpha.DataprocMetastore.ListBackups].
             parent (str):
@@ -1510,7 +1510,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def get_backup(
         self,
-        request: metastore.GetBackupRequest = None,
+        request: Union[metastore.GetBackupRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1520,7 +1520,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Gets details of a single backup.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.GetBackupRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.GetBackupRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.GetBackup][google.cloud.metastore.v1alpha.DataprocMetastore.GetBackup].
             name (str):
@@ -1581,7 +1581,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def create_backup(
         self,
-        request: metastore.CreateBackupRequest = None,
+        request: Union[metastore.CreateBackupRequest, dict] = None,
         *,
         parent: str = None,
         backup: metastore.Backup = None,
@@ -1593,7 +1593,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Creates a new Backup in a given project and location.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.CreateBackupRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.CreateBackupRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.CreateBackup][google.cloud.metastore.v1alpha.DataprocMetastore.CreateBackup].
             parent (str):
@@ -1692,7 +1692,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
 
     def delete_backup(
         self,
-        request: metastore.DeleteBackupRequest = None,
+        request: Union[metastore.DeleteBackupRequest, dict] = None,
         *,
         name: str = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
@@ -1702,7 +1702,7 @@ class DataprocMetastoreClient(metaclass=DataprocMetastoreClientMeta):
         r"""Deletes a single backup.
 
         Args:
-            request (google.cloud.metastore_v1alpha.types.DeleteBackupRequest):
+            request (Union[google.cloud.metastore_v1alpha.types.DeleteBackupRequest, dict]):
                 The request object. Request message for
                 [DataprocMetastore.DeleteBackup][google.cloud.metastore.v1alpha.DataprocMetastore.DeleteBackup].
             name (str):
